api.currentuser.v1.permission package — Argus-Toolbelt 1.0 documentation

# api.currentuser.v1.permission package

## Submodules

## api.currentuser.v1.permission.permission module

Autogenerated API

`api.currentuser.v1.permission.permission.` `check_permission`(function: str, customerID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Validate current user permission to perform function on specific customer (PUBLIC)

  Return type: | `dict`
  Parameters: | function (str) – Function name customerID (int) – Customer ID
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 ForbiddenPermissionException – on 403 UserNotFoundException – on 404
  Returns: | {“offset”: 814, “limit”: 884, “responseCode”: 200, “count”: 866, “data”: {}, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Allow few something sit western true act.”, “messageTemplate”: “Per toward fact strong speak section message.”, “field”: “Attack place indeed pass fish laugh.”, “parameter”: {}, “timestamp”: 1436314859}], “currentPage”: 787, “size”: 724}

## Module contents